<?php

/**
 * Helper function that returns the blocks delta according to the menu name.
 *
 * @param string $menu_machine_name
 *   The name of the menu.
 *
 * @return string
 *   The block delta.
 */
function _better_jump_menu_block_get_block_id($menu_machine_name) {
  return substr(sha1($menu_machine_name), 0, -32);
}

/**
 * Helper function return the menu name according to the block delta.
 *
 * @param string $delta
 *   The block delta.
 *
 * @return
 */
function _better_jump_menu_block_get_menu($delta) {
  foreach (menu_get_menus(TRUE) as $name => $title) {
    if (_better_jump_menu_block_get_block_id($name) == $delta) {
      return $name . '::' . $title;
    }
  }

  return FALSE;
}

/**
 * Convert the result of menu_tree_output to an option array.
 *
 * @param $build
 * @param $options
 * @param $configuration
 *
 * @return mixed
 */
function _better_jump_menu_convert_to_options_array(&$build, &$options, $configuration) {
  foreach(element_children($build) as $key) {
    $value = uniqid() . '::' . url($build[$key]['#href'], array('absolute' => TRUE));
    $indent = str_repeat($configuration['indent'], $build[$key]['#original_link']['depth'] - 1);
    $options[$value] = trim(sprintf('%s %s', $indent, trim($build[$key]['#title'])));
    _better_jump_menu_convert_to_options_array($build[$key]['#below'], $options, $configuration);
  }
}

/**
 * Get the configuration for a better jump menu block
 *
 * @param $menu_machine_name
 *   The menu machine name.
 *
 * @return array
 */
function _better_jump_menu_get_block_default_configuration($menu_machine_name) {
  $configuration = variable_get('better_jump_menu_block_configuration', array());

  $defaults = array(
    'hide' => FALSE,
    'path' => '',
    'indent' => '-',
    'text' => t('Go'),
    'title' => '',
    'choose' => t('- Choose -'),
    'inline' => TRUE,
  );

  return isset($configuration[$menu_machine_name]) ? $configuration[$menu_machine_name] + $defaults : $defaults;
}
